export default {
  'index': { display: 'hidden' },
  'backend-extensions': 'Backend Extensions',
  'frontend-extensions': 'Frontend Extensions',
  'api-reference': 'API Reference',
  'migration-guide': 'Migration Guide'
}
