{% extends "admin/change_list.html" %}
{% load static %}

{% block footer %}
    {{ block.super }}

    {# Documentation FAB button - rendered at end of body #}
    {% if documentation_config %}
        {% include "django_admin/documentation_block.html" %}
    {% endif %}
{% endblock %}
