export default {
  'index': 'Overview',
  'getting-started': 'Getting Started',
  'concepts': 'Concepts',
  'architecture': 'Architecture',
  'configuration': 'Configuration',
  'authentication': 'Authentication',
  'async-support': 'Async Support',
  'streaming-patterns': 'Streaming Patterns',
  'proto-generation': 'Proto Generation',
  'dynamic-invocation': 'Dynamic Invocation',
  'rest-api': 'REST API',
  'troubleshooting': 'Troubleshooting',
  'faq': 'FAQ'
}
