export default {
  'index': { display: 'hidden' },
  'app-structure': 'App Structure',
  'models': 'Models',
  'managers': 'Managers & QuerySets',
  'services': 'Service Layer',
  'viewsets': 'ViewSets & Actions',
  'serializers': 'Serializers',
  'urls-routing': 'URL Routing',
  'admin': 'Admin Configuration',
  'tasks': 'Background Tasks',
  'testing': 'Testing',
}
