export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',

  // --- Core Infrastructure ---
  'django-cf': 'Cloudflare D1',
  'django-monitor': 'Monitor',
  'django-logging': 'Logging',
  'django-health': 'Health Checks',

  // --- Communication ---
  'django-grpc': 'gRPC Server',
  'django-centrifugo': 'Centrifugo WebSocket',
  'django-rq': 'Django-RQ Tasks',
  'django-email': 'Email',
  'django-telegram': 'Telegram Bot',

  // --- Admin & UI ---
  'django-admin': 'Django Admin',
  'django-unfold': 'Unfold Theme',
  'streamlit-admin': 'Streamlit Admin',
  'django-drf-theme': 'DRF Theme',

  // --- Code Generation ---
  'django-codegen': 'Code Generation',
  'django-client': 'API Client',
  'django-fastapi': 'FastAPI ORM',
  'django-ogimage': 'OG Images',

  // --- AI & LLM ---
  'django-llm': 'LLM Integration',
  'django-llm-monitoring': 'LLM Monitoring',

  // --- Data & Tools ---
  'django-currency': 'Currency',
  'django-import-export': 'Import/Export',
  'django-cleanup': 'File Cleanup',
  'django-tailwind': 'Tailwind CSS',

  // --- Networking ---
  'django-ngrok': 'Ngrok Tunnels',
}
