from ._base import OGImagePreset

LIGHT = OGImagePreset(
    name="light",
    bg_color="#ffffff",
    bg_color2="#f9fafb",
    text_color="#111827",
    accent_color="#3b82f6",
    style="light",
)

LIGHT_GRAY = OGImagePreset(
    name="light_gray",
    bg_color="#f9fafb",
    bg_color2="#f3f4f6",
    text_color="#111827",
    accent_color="#6366f1",
    style="light",
)

LIGHT_WARM = OGImagePreset(
    name="light_warm",
    bg_color="#fffbeb",
    bg_color2="#fef3c7",
    text_color="#78350f",
    accent_color="#f59e0b",
    style="light",
)

LIGHT_GREEN = OGImagePreset(
    name="light_green",
    bg_color="#f0fdf4",
    bg_color2="#dcfce7",
    text_color="#14532d",
    accent_color="#16a34a",
    style="light",
)
