export default {
  'getting-started': 'Getting Started',
  'core': 'Core',
  'configuration': 'Configuration',
  'database': 'Database',
  'features': 'Features',
  'extensions': 'Extensions',
  'cli': 'CLI Tools',
  'frontend': 'Frontend (Next.js)',
  'guides': 'Guides',
  'deployment': 'Deployment',
  'api': 'API Reference',
  '---': {
    type: 'separator'
  },
  'business': 'Business',
  'updates': 'Updates'
}
