export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',
  'patterns': 'Integration Patterns',
  'auth': { display: 'hidden' },
  'auth-system': { display: 'hidden' },
  'oauth': 'OAuth',
}
