export default {
  'index': { display: 'hidden' },
  'modules': 'Modules',
  'built-in-apps': 'Bundled Extensions',
  'integrations': 'Integrations',
  'tools': 'Tools & Utilities',
  'api-generation': 'API Generation',
  'drf-guide': 'DRF Guide'
}
