export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',
  'project-structure': 'Project Structure',
  'configuration': 'Configuration',
  'multi-database': 'Multi-Database',
  'admin-interface': 'Admin Interface',
  'api-documentation': 'API Documentation',
  'authentication': 'Authentication',
  'service-integrations': 'Service Integrations',
  'deployment': 'Deployment'
}
