# Auto-generated by DjangoCFG - see CLAUDE.md

from __future__ import annotations
import datetime
from typing import Any

from pydantic import BaseModel, ConfigDict, Field


class DRFHealthCheck(BaseModel):
    """
    Serializer for health check response.

    Response model (includes read-only fields).
    """

    model_config = ConfigDict(
        validate_assignment=True,
        extra="allow",
        frozen=False,
    )

    status: str = Field(description='Overall health status: healthy, ...')
    timestamp: datetime.datetime = Field(description='Timestamp of the health check')
    service: str = Field(description='Service name')
    version: str = Field(description='Django-CFG version')
    checks: dict[str, Any] = Field(description='Detailed health checks for datab...')
    environment: dict[str, Any] = Field(description='Environment information')
    links: dict[str, Any] | None = Field(None, description='Useful API endpoint links')



class QuickHealth(BaseModel):
    """
    Serializer for quick health check response.

    Response model (includes read-only fields).
    """

    model_config = ConfigDict(
        validate_assignment=True,
        extra="allow",
        frozen=False,
    )

    status: str = Field(description='Quick health status: ok or error')
    timestamp: datetime.datetime = Field(description='Timestamp of the health check')
    error: str | None = Field(None, description='Error message if health check fa...')



