export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',
  'development': 'Development',
  'production': 'Production',
  'configuration': 'Configuration',
  'build-optimization': 'Build Optimization',
  'troubleshooting': 'Troubleshooting'
}
