export default {
  'overview': 'Overview',
  'vision': 'Vision & OCR',
  'image-generation': 'Image Generation',
  'text-client': 'Text Client',
  'cost-tracking': 'Cost Tracking',
  'caching': 'Caching',
  'balance-monitoring': 'Balance Monitoring'
}
