// Auto-generated Go module for Centrifugo WebSocket RPC client
// Dependencies are fetched via Go module proxy (proxy.golang.org by default)
// To use custom proxy: export GOPROXY=https://your-proxy.com
module {{ module_path }}

go 1.21

require (
	nhooyr.io/websocket v1.8.10
)
