export default {
  'index': { display: 'hidden' },
  'async-orm': 'Async ORM',
  'channels-asgi': 'Channels & ASGI',
  'django-testing': 'Django Testing',
  'quality-gates': 'Quality Gates',
  'route-debug': 'Route Debug',
}
