export default {
  index: {
    title: 'Releases',
    theme: {
      layout: 'full',
      typesetting: 'article'
    }
  },
  'v1-4-42': {
    title: 'v1.4.42',
    theme: {
      typesetting: 'article'
    }
  }
}
