export default {
  'index': { display: 'hidden' },
  'app-design': 'App Design Guide',
  'testing': 'Testing',
  'module-design': 'Module Design Guide',
  'django-runtime': 'Django Runtime Guide',
  'sample-project': 'Sample Project',
  'examples': 'Examples',
  'ai-integration': 'AI Integration',
  'multi-database': 'Multi-Database',
  'production-config': 'Production Config',
  'migration-guide': 'Migration Guide',
  'django-configuration-problems-solved': 'Django Configuration Problems Solved',
  'docker': 'Docker',
  'troubleshooting': 'Troubleshooting',
  'faq': 'FAQ'
}
