export default {
  'index': { display: 'hidden' },
  'architecture': 'Architecture',
  'type-safety': 'Type Safety',
  'builder-pattern': 'Builder Pattern',
  'generator-pattern': 'Generator Pattern',
  'django-integration': 'Django Integration',
  'registry': 'Registry',
  'routing': 'Routing',
  'middleware': 'Middleware',
  'cors': 'CORS',
  'rate-limiting': 'Rate Limiting',
  'startup': 'Startup',
  'utilities': 'Utilities',
  'encryption': 'Encryption'
}
