export default {
  'index': 'Overview',
  'frontend': 'Frontend Integration',
  'otp': 'OTP & Brute-Force Protection',
  'jwt': 'JWT Configuration',
  'two-factor': 'Two-Factor Auth (2FA)',
  'oauth': 'OAuth (GitHub)',
  'login-alerts': 'Login Alerts',
}
