export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',
  'environment-setup': 'Environment Setup',
  'security': 'Security',
  'logging': 'Logging',
  'monitoring': 'Monitoring'
}
