export default {
  index: {
    title: 'Security',
    theme: {
      layout: 'full',
      typesetting: 'article'
    }
  },
  'nextjs-cve-2025-55184-55183': {
    title: 'CVE-2025-55184 & 55183: DoS & Source Exposure',
    theme: {
      typesetting: 'article'
    }
  },
  'nextjs-cve-2025-66478': {
    title: 'CVE-2025-66478: Next.js RCE',
    theme: {
      typesetting: 'article'
    }
  }
}
